pub type ChannelRegistration = fn() -> RegisteredChannel;Expand description
Startup constructor collected from an externally linked channel crate.
pub type ChannelRegistration = fn() -> RegisteredChannel;Startup constructor collected from an externally linked channel crate.